powered by
Computes average classification accuracy.
accuracy( pred, actual, cutoff = NULL, reference = NULL )
The computed average classification accuracy (numeric value).
a numerical vector of estimated values.
a numerical vector of actual values.
cutoff value for the case that pred is vector of probabilites.
pred
a factor of classes to be used as the true results.
.
Reza Mohammadi a.mohammadi@uva.nl and Kevin Burke kevin.burke@ul.ie
conf.mat, mse, mae
conf.mat
mse
mae
pred = c( "no", "yes", "yes", "no", "no", "yes", "no", "no" ) actual = c( "yes", "no", "yes", "no", "no", "no", "yes", "yes" ) accuracy( pred, actual )
Run the code above in your browser using DataLab