| advertising | R Documentation |
the dataset is from an anonymous organisation's social media ad campaign. the advertising dataset contains 11 features and 1143 records.
data(advertising)
the advertising dataset, as a data frame, contains 1143 rows and 11 columns (variables/features). the 11 variables are:
ad.id: an unique ID for each ad.
xyz.campaign.id: an ID associated with each ad campaign of XYZ company.
fb.campaign.id: an ID associated with how Facebook tracks each campaign.
age: age of the person to whom the ad is shown.
gender: gender of the person to whim the add is shown.
interest: a code specifying the category to which the person's interest belongs (interests are as mentioned in the person's Facebook public profile).
impressions: the number of times the ad was shown.
clicks: number of clicks on for that ad.
spend: amount paid by company xyz to Facebook, to show that ad.
conversion: total number of people who enquired about the product after seeing the ad.
approved: total number of people who bought the product after seeing the ad.
For more information related to the dataset see:
https://www.kaggle.com/loveall/clicks-conversion-tracking
This dataset is from:
https://www.kaggle.com/loveall/clicks-conversion-tracking
Reza Mohammadi (2025). Data Science Foundations and Machine Learning with R: From Data to Decisions. https://book-data-science-r.netlify.app.
bank,
churn_mlc,
churn,
churn_tel,
adult,
risk,
cereal,
marketing,
drug,
house,
house_price,
red_wines,
white_wines,
insurance,
caravan,
fertilizer,
corona
data(advertising)
str(advertising)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.