| cereal | R Documentation |
This dataset contains nutrition information for 77 breakfast cereals and includes 16 variables. the "rating" column is our target as a rating of the cereals (Possibly from Consumer Reports?).
data(cereal)
the cereal dataset, as a data frame, contains 77 rows (breakfast cereals) and 16 columns (variables/features). the 16 variables are:
name: Name of cereal.
manuf: Manufacturer of cereal, coded into seven categories: "A" for American Home Food Products, "G" for General Mills, "K" for Kelloggs, "N" for Nabisco, "P" for Post, "Q" for Quaker Oats, and "R" for Ralston Purina.
type: cold or hot.
calories: calories per serving.
protein: grams of protein.
fat: grams of fat.
sodium: milligrams of sodium.
fiber: grams of dietary fiber.
carbo: grams of complex carbohydrates.
sugars: grams of sugars.
potass: milligrams of potassium.
vitamins: vitamins and minerals - 0, 25, or 100, indicating the typical percentage of FDA recommended.
shelf: display shelf (1, 2, or 3, counting from the floor).
weight: weight in ounces of one serving.
cups: number of cups in one serving.
rating: a rating of the cereals (Possibly from Consumer Reports?).
For more information related to the dataset see
https://www.openml.org/search?type=data&status=any&id=1095&sort=runs
This dataset is originally from
https://lib.stat.cmu.edu/DASL/Datafiles/Cereals.html
Reza Mohammadi (2025). Data Science Foundations and Machine Learning with R: From Data to Decisions. https://book-data-science-r.netlify.app.
bank,
churn_mlc,
churn,
churn_tel,
adult,
risk,
advertising,
marketing,
drug,
house,
house_price,
red_wines,
white_wines,
insurance,
caravan,
fertilizer,
corona
data(cereal)
str(cereal)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.