marketing: marketing data set

marketingR Documentation

marketing data set

Description

the marketing dataset contains 8 features and 40 records as 40 days that report how much we spent, how many clicks, impressions and transactions we got, whether or not a display campaign was running, as well as our revenue, click-through-rate and conversion rate. the target feature is revenue and the remaining 7 variables are predictors.

Usage

 data(marketing) 

Format

the marketing dataset, as a data frame, contains 40 rows and 8 columns (variables/features). the 8 variables are:

  • spend: daily send of money on PPC (apy-per-click).

  • clicks: number of clicks on for that ad.

  • impressions: amount of impressions per day.

  • display: whether or not a display campaign was running.

  • transactions: number of transactions per day.

  • click.rate: click-through-rate.

  • conversion.rate: conversion rate.

  • revenue: daily revenue.

Details

For more information related to the dataset see:
https://github.com/chrisBow/marketing-regression-part-one

This dataset comes from:
https://github.com/chrisBow/marketing-regression-part-one

References

Reza Mohammadi (2025). Data Science Foundations and Machine Learning with R: From Data to Decisions. https://book-data-science-r.netlify.app.

See Also

bank, churn_mlc, churn, churn_tel, adult, risk, cereal, advertising, drug, house, house_price, red_wines, white_wines, insurance, caravan, fertilizer, corona

Examples

data(marketing)
str(marketing)

liver documentation built on Feb. 19, 2026, 1:07 a.m.