prop.conf: Confdidence interval for proportion

View source: R/prop.conf.R

prop.confR Documentation

Confdidence interval for proportion

Description

Compute a confidence interval for the proportion of a response variable using the normal distribution.

Usage

prop.conf(x, n, conf = 0.95, ...)

Arguments

x

a vector of counts of successes, a one-dimensional table with two entries, or a two-dimensional table (or matrix) with 2 columns, giving the counts of successes and failures, respectively.

n

a vector of counts of trials; ignored if x is a matrix or a table.

conf

confidence level of the interval.

...

further arguments to be passed to prop.test.

Value

A vector with two values: lower and upper confidence limits for the proportion of the response variable.

Author(s)

Reza Mohammadi a.mohammadi@uva.nl

Examples

data(churn_mlc)

prop.conf(table(churn_mlc$churn), conf = 0.9)

liver documentation built on Feb. 19, 2026, 1:07 a.m.