skim: Skim a data frame to get useful summary statistics
Description
skim() provides an overview of a data frame asan alternative to summary(). This function is a wrapper for the skimr::skim() function of R package skimr.
Usage
skim( data, hist = TRUE, ... )
Arguments
data
a data frame or matrix.
hist
Logical: TRUE (default) to report the histogram of each variable.
...
columns to select for skimming. The default is to skim all columns.